aimaster
========

Artificial Neural Network learning and experimentation tools with live visualization.  
(NOTE: Donot use pipe visualization with very large networks 😅.)  
  
This module needs `numpy` and `scipy` installed.
And `matplotlib` for visualization.

Feel free to experiment with aimaster.  

## Installation

Use `pip install aimaster` or `pip3 install aimaster` to install package from PyPI.  